@@ -1,12 +1,15 @@
-
+#' @import yaml
 #' @S3method print fs_object
 print.fs_object <- function(x, ...){
-  summary_fs_details(x)
+  cat(as.yaml(x))
+# x
 }
 
+#' @import yaml
 #' @S3method summary fs_object
 summary.fs_object <- function(object, ...){
-  summary_fs_details(object)
+  cat(as.yaml(object))
+# object
 }
 
 
