@@ -4,9 +4,11 @@
 #' @author Carl Boettiger \email{cboettig@@gmail.com}
 #' @param article_id the id number of the article 
 #' @param title for the article (to replace original title)
+#' @param mine Set to \code{TRUE} if it refers to an item on your own account
 #' @param description of the article (replaces original designation)
 #' @param type one of: dataset, figure, media, poster, or paper (replaces original designation)
 #' @param session (optional) the authentication credentials from \code{\link{fs_auth}}. 
+#' @param debug return httr PUT request visibly?
 #' @return output of PUT request (invisibly)
 #' @seealso \code{\link{fs_auth}}, \code{\link{fs_add_tags}}
 #' @references \url{http://api.figshare.com}
@@ -14,14 +16,15 @@
 #' @import RJSONIO
 #' @export
 #' @examples \dontrun{
-#' fs_update(138, title="New title") 
+#' fs_update(138, title = "New title") 
 #' }
 fs_update <- 
-function(article_id, title=NA, description=NA, type = NA,
-         session = fs_get_auth()){
+function(article_id, title = NA, description = NA, type  =  NA, mine = TRUE,
+         session = fs_get_auth(), debug = FALSE){
 
   ## grab the article details and use those as defaults
-  details <- fs_details(article_id, session)
+  details <- fs_details(article_id, mine = mine, 
+                        session = session)
   if(is.na(title))
     title <- details$title
   if(is.na(description))
@@ -30,14 +33,18 @@ function(article_id, title=NA, description=NA, type = NA,
     type <- details$defined_type
 
   base <- "http://api.figshare.com/v1"
-  method <- paste("my_data/articles", article_id, sep= "/")
-  request <- paste(base, method, sep="/")
-  meta <- toJSON(list("title"=title, "description"=description, 
-                      "defined_type"=type))
-  config <- c(verbose(), session, 
+  method <- paste("my_data/articles", article_id, sep = "/")
+  request <- paste(base, method, sep = "/")
+  meta <- toJSON(list("title" = title, 
+                      "description" = description, 
+                      "defined_type" = type))
+  config <- c(config(token = session), 
               add_headers("Content-Type" = "application/json"))
-  post <- PUT(request, config=config, body=meta)
-  invisible(post)
+  post <- PUT(request, config = config, body = meta)
+  if(debug)
+    post
+  else
+    invisible(post)
 }
 
 
